{% load i18n cms_tags menu_tags leprikon_tags sekizai_tags static ganalytics %}
<!DOCTYPE html>
<html lang="cs-CZ">

<head>
    <meta charset="UTF-8" />
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <!-- The above 3 meta tags *must* come first in the head; any other head content must come *after* these tags -->

    <title>
        {% block title %}{% endblock %} {% include 'leprikon/title.txt' %}
    </title>

    <!-- Bootstrap -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/css/bootstrap.min.css" integrity="sha512-Dop/vW3iOtayerlYAqCgkVr2aTr2ErwwTYOvRFUpzl2VhCMJyjQF0Q9TjUXIo6JhuM/3i0vVEt2e/7QQmnHQqw==" crossorigin="anonymous" referrerpolicy="no-referrer" />

    <!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
        <script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
        <script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
    <![endif]-->

    <!-- Stylesheet -->
    <link rel="stylesheet" type="text/css" media="all" href="{% static 'leprikon/css/layout.css' %}"/>
    <link rel="stylesheet" type="text/css" media="all" href="{% static 'leprikon/css/colors.css' %}"/>
    {% render_block "css" %}

    <!-- jQuery (necessary for Bootstrap's JavaScript plugins) -->
    <script src="{% static 'leprikon/lib/jquery.min.js' %}"></script>

    <!-- Include all compiled plugins (below), or include individual files as needed -->
    <script src="https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/js/bootstrap.min.js" integrity="sha512-oBTprMeNEKCnqfuqKd6sbvFzmFQtlXS3e0C/RGFV0hD6QzhHV+ODfaQbAlmY6/q0ubbwlAM/nCJjkrgA3waLzg==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>

    <!-- Shortcut icon -->
    <link rel="shortcut icon" href="{% static 'favicon.ico' %}" />

    {% if backends %}
    <!-- Bootstrap social -->
    <link rel="stylesheet" type="text/css" media="all" href="{% static 'leprikon/lib/font-awesome/css/font-awesome.min.css' %}"/>
    <link rel="stylesheet" type="text/css" media="all" href="{% static 'leprikon/lib/bootstrap-social.min.css' %}"/>
    {% endif %}

    {% block extrahead %}{% endblock %}
</head>

<body>
{% cms_toolbar %}
    <div id="header">
        <div class="container">
            <div class="col-sm-9">
                {% block brand %}
                    {% static_placeholder "brand" or %}<a href="/"><img src="{% static 'leprikon/img/logo-horizontal.png' %}" height="80"/></a>{% endstatic_placeholder %}
                {% endblock %}
            </div>
            <div class="col-sm-3">
                {% school_year_form %}
                {% include 'leprikon/user_dropdown.html' %}
            </div>
        </div>
    </div>

    <div id="body">
        <div class="container">
            <div class="row">
                <div class="col-sm-9" id="content">
                    {% include 'leprikon/modal_messages.html' %}
                    {% block content %}{% endblock %}
                </div>
                <div class="col-sm-3" id="sidebar">
                    <nav class="list-group">
                        {% block menu %}{% show_menu 0 100 0 100 'leprikon/menu.html' 'CMSMenu,LeprikonMenu' %}{% endblock %}
                    </nav>
                </div>
            </div>
        </div>

        <a id="leprikon" href="https://leprikon.cz" target="_blank" title="{% trans 'Powered by Leprikón Information System' %}"><span>{% trans 'Powered by Leprikón Information System' %}</span></a>
    </div>

    {% render_block "js" %}

    <script>
        CMS.$(document).ready(function() {
            window.setTimeout(function() {
                CMS.$('html').removeAttr('data-touch-action');
            }, 2000);
        });
    </script>

</body>
</html>
